/*
 * Copyright (C) 2010 Leandro Aparecido <lehphyro@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.code.mjl.factory;

import java.io.*;

import com.google.code.mjl.*;
import com.google.code.mjl.impl.*;

public class StdoutLogAdapterFactory implements LogAdapterFactory {
	private static final LogAdapter LOGGER = new LogAdapter() {
		public boolean isEnabled(Log.Level level) {
			return true;
		}

		public void log(LogEvent logEvent) {
			PrintWriter writer = new PrintWriter(System.out);
			LogUtils.toString(logEvent, writer);
			writer.flush();
			System.out.println();
		}
	};

	public LogAdapter create(String logName) {
		return LOGGER;
	}

	public void shutdown() {
		// do nothing
	}
}
