/*
 * Copyright (C) 2010 Leandro Aparecido <lehphyro@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.code.mjl.formatter.impl;

import java.util.*;

import com.google.code.mjl.formatter.*;

public class DefaultMessageFormatterFactory implements MessageFormatterFactory {

	private static final String PREFIX = "mjl.formatter.default.";

	private final Locale locale;

	public DefaultMessageFormatterFactory() {
		String language = System.getProperty(PREFIX + "language", null);
		String country = System.getProperty(PREFIX + "country", null);
		String variant = System.getProperty(PREFIX + "variant", null);

		if (variant != null) {
			locale = new Locale(language, country, variant);
		} else if (country != null) {
			locale = new Locale(language, country);
		} else if (language != null) {
			locale = new Locale(language);
		} else {
			locale = Locale.getDefault();
		}
	}

	public MessageFormatter create() {
		return new DefaultMessageFormatter(locale);
	}
}
