/*
 * Copyright (C) 2010 Leandro Aparecido <lehphyro@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.code.mjl.guice;

import java.lang.reflect.*;

import com.google.code.mjl.*;
import com.google.inject.*;
import com.google.inject.spi.*;

public class InjectLogTypeListener implements TypeListener {

	@Override
	public <I> void hear(TypeLiteral<I> type, TypeEncounter<I> encounter) {
		Class<?> currentClass = type.getRawType();
		while (currentClass != null && currentClass != Enum.class && currentClass != Object.class) {
			for (Field field : currentClass.getDeclaredFields()) {
				if (field.getType() == Log.class && field.isAnnotationPresent(InjectLog.class)) {
					InjectLog annotation = field.getAnnotation(InjectLog.class);
					encounter.register(new InjectLogMembersInjector<I>(type.getRawType(), field, annotation.value()));
				}
			}
			currentClass = currentClass.getSuperclass();
		}
	}

}
